==> openshift-model-4.13.3-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NamedTagEventListBuilder extends NamedTagEventListFluentImpl<NamedTagEventListBuilder> implements VisitableBuilder<NamedTagEventList,NamedTagEventListBuilder> {

    NamedTagEventListFluent<?> fluent;
    Boolean validationEnabled;

    public NamedTagEventListBuilder() { 
        this(true);
    }


    public NamedTagEventListBuilder(Boolean validationEnabled) { 
        this(new NamedTagEventList(), validationEnabled);
    }


    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent) { 
        this(fluent, true);
    }


    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new NamedTagEventList(), validationEnabled);
    }


    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,NamedTagEventList instance) { 
        this(fluent, instance, true);
    }


    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,NamedTagEventList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withConditions(instance.getConditions()); 
        fluent.withItems(instance.getItems()); 
        fluent.withTag(instance.getTag()); 
        this.validationEnabled = validationEnabled; 
    }


    public NamedTagEventListBuilder(NamedTagEventList instance) { 
        this(instance,true);
    }


    public NamedTagEventListBuilder(NamedTagEventList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withConditions(instance.getConditions()); 
        this.withItems(instance.getItems()); 
        this.withTag(instance.getTag()); 
        this.validationEnabled = validationEnabled; 
    }


    public NamedTagEventList build() {
        NamedTagEventList buildable = new NamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NamedTagEventListBuilder extends NamedTagEventListFluentImpl<NamedTagEventListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<NamedTagEventList,NamedTagEventListBuilder> {

    NamedTagEventListFluent<?> fluent;
    Boolean validationEnabled;

    public NamedTagEventListBuilder() {
        this(true);
    }

    public NamedTagEventListBuilder(Boolean validationEnabled) {
        this(new NamedTagEventList(), validationEnabled);
    }

    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent) {
        this(fluent, true);
    }

    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new NamedTagEventList(), validationEnabled);
    }

    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,NamedTagEventList instance) {
        this(fluent, instance, true);
    }

    public NamedTagEventListBuilder(NamedTagEventListFluent<?> fluent,NamedTagEventList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConditions(instance.getConditions()); 
        fluent.withItems(instance.getItems()); 
        fluent.withTag(instance.getTag()); 
        this.validationEnabled = validationEnabled; 
    }

    public NamedTagEventListBuilder(NamedTagEventList instance) {
        this(instance,true);
    }

    public NamedTagEventListBuilder(NamedTagEventList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withConditions(instance.getConditions()); 
        this.withItems(instance.getItems()); 
        this.withTag(instance.getTag()); 
        this.validationEnabled = validationEnabled; 
    }

    public NamedTagEventList build() {
        NamedTagEventList buildable = new NamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
